Class: Aws::Greengrass::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Greengrass::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-greengrass/client.rb,
sig/client.rbs
Overview
An API client for Greengrass. To construct a client, you need to configure a :region and :credentials.
client = Aws::Greengrass::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateRoleToGroupResponseSuccess, _AssociateServiceRoleToAccountResponseSuccess, _CreateConnectorDefinitionResponseSuccess, _CreateConnectorDefinitionVersionResponseSuccess, _CreateCoreDefinitionResponseSuccess, _CreateCoreDefinitionVersionResponseSuccess, _CreateDeploymentResponseSuccess, _CreateDeviceDefinitionResponseSuccess, _CreateDeviceDefinitionVersionResponseSuccess, _CreateFunctionDefinitionResponseSuccess, _CreateFunctionDefinitionVersionResponseSuccess, _CreateGroupCertificateAuthorityResponseSuccess, _CreateGroupResponseSuccess, _CreateGroupVersionResponseSuccess, _CreateLoggerDefinitionResponseSuccess, _CreateLoggerDefinitionVersionResponseSuccess, _CreateResourceDefinitionResponseSuccess, _CreateResourceDefinitionVersionResponseSuccess, _CreateSoftwareUpdateJobResponseSuccess, _CreateSubscriptionDefinitionResponseSuccess, _CreateSubscriptionDefinitionVersionResponseSuccess, _DeleteConnectorDefinitionResponseSuccess, _DeleteCoreDefinitionResponseSuccess, _DeleteDeviceDefinitionResponseSuccess, _DeleteFunctionDefinitionResponseSuccess, _DeleteGroupResponseSuccess, _DeleteLoggerDefinitionResponseSuccess, _DeleteResourceDefinitionResponseSuccess, _DeleteSubscriptionDefinitionResponseSuccess, _DisassociateRoleFromGroupResponseSuccess, _DisassociateServiceRoleFromAccountResponseSuccess, _GetAssociatedRoleResponseSuccess, _GetBulkDeploymentStatusResponseSuccess, _GetConnectivityInfoResponseSuccess, _GetConnectorDefinitionResponseSuccess, _GetConnectorDefinitionVersionResponseSuccess, _GetCoreDefinitionResponseSuccess, _GetCoreDefinitionVersionResponseSuccess, _GetDeploymentStatusResponseSuccess, _GetDeviceDefinitionResponseSuccess, _GetDeviceDefinitionVersionResponseSuccess, _GetFunctionDefinitionResponseSuccess, _GetFunctionDefinitionVersionResponseSuccess, _GetGroupCertificateAuthorityResponseSuccess, _GetGroupCertificateConfigurationResponseSuccess, _GetGroupResponseSuccess, _GetGroupVersionResponseSuccess, _GetLoggerDefinitionResponseSuccess, _GetLoggerDefinitionVersionResponseSuccess, _GetResourceDefinitionResponseSuccess, _GetResourceDefinitionVersionResponseSuccess, _GetServiceRoleForAccountResponseSuccess, _GetSubscriptionDefinitionResponseSuccess, _GetSubscriptionDefinitionVersionResponseSuccess, _GetThingRuntimeConfigurationResponseSuccess, _ListBulkDeploymentDetailedReportsResponseSuccess, _ListBulkDeploymentsResponseSuccess, _ListConnectorDefinitionVersionsResponseSuccess, _ListConnectorDefinitionsResponseSuccess, _ListCoreDefinitionVersionsResponseSuccess, _ListCoreDefinitionsResponseSuccess, _ListDeploymentsResponseSuccess, _ListDeviceDefinitionVersionsResponseSuccess, _ListDeviceDefinitionsResponseSuccess, _ListFunctionDefinitionVersionsResponseSuccess, _ListFunctionDefinitionsResponseSuccess, _ListGroupCertificateAuthoritiesResponseSuccess, _ListGroupVersionsResponseSuccess, _ListGroupsResponseSuccess, _ListLoggerDefinitionVersionsResponseSuccess, _ListLoggerDefinitionsResponseSuccess, _ListResourceDefinitionVersionsResponseSuccess, _ListResourceDefinitionsResponseSuccess, _ListSubscriptionDefinitionVersionsResponseSuccess, _ListSubscriptionDefinitionsResponseSuccess, _ListTagsForResourceResponseSuccess, _ResetDeploymentsResponseSuccess, _StartBulkDeploymentResponseSuccess, _StopBulkDeploymentResponseSuccess, _UpdateConnectivityInfoResponseSuccess, _UpdateConnectorDefinitionResponseSuccess, _UpdateCoreDefinitionResponseSuccess, _UpdateDeviceDefinitionResponseSuccess, _UpdateFunctionDefinitionResponseSuccess, _UpdateGroupCertificateConfigurationResponseSuccess, _UpdateGroupResponseSuccess, _UpdateLoggerDefinitionResponseSuccess, _UpdateResourceDefinitionResponseSuccess, _UpdateSubscriptionDefinitionResponseSuccess, _UpdateThingRuntimeConfigurationResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_role_to_group(params = {}) ⇒ Types::AssociateRoleToGroupResponse
Associates a role with a group.
-
#associate_service_role_to_account(params = {}) ⇒ Types::AssociateServiceRoleToAccountResponse
Associates a role with your account.
-
#create_connector_definition(params = {}) ⇒ Types::CreateConnectorDefinitionResponse
Creates a connector definition.
-
#create_connector_definition_version(params = {}) ⇒ Types::CreateConnectorDefinitionVersionResponse
Creates a version of a connector definition which has already been defined.
-
#create_core_definition(params = {}) ⇒ Types::CreateCoreDefinitionResponse
Creates a core definition.
-
#create_core_definition_version(params = {}) ⇒ Types::CreateCoreDefinitionVersionResponse
Creates a version of a core definition that has already been defined.
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates a deployment.
-
#create_device_definition(params = {}) ⇒ Types::CreateDeviceDefinitionResponse
Creates a device definition.
-
#create_device_definition_version(params = {}) ⇒ Types::CreateDeviceDefinitionVersionResponse
Creates a version of a device definition that has already been defined.
-
#create_function_definition(params = {}) ⇒ Types::CreateFunctionDefinitionResponse
Creates a Lambda function definition which contains a list of Lambda functions and their configurations to be used in a group.
-
#create_function_definition_version(params = {}) ⇒ Types::CreateFunctionDefinitionVersionResponse
Creates a version of a Lambda function definition that has already been defined.
-
#create_group(params = {}) ⇒ Types::CreateGroupResponse
Creates a group.
-
#create_group_certificate_authority(params = {}) ⇒ Types::CreateGroupCertificateAuthorityResponse
Creates a CA for the group.
-
#create_group_version(params = {}) ⇒ Types::CreateGroupVersionResponse
Creates a version of a group which has already been defined.
-
#create_logger_definition(params = {}) ⇒ Types::CreateLoggerDefinitionResponse
Creates a logger definition.
-
#create_logger_definition_version(params = {}) ⇒ Types::CreateLoggerDefinitionVersionResponse
Creates a version of a logger definition that has already been defined.
-
#create_resource_definition(params = {}) ⇒ Types::CreateResourceDefinitionResponse
Creates a resource definition which contains a list of resources to be used in a group.
-
#create_resource_definition_version(params = {}) ⇒ Types::CreateResourceDefinitionVersionResponse
Creates a version of a resource definition that has already been defined.
-
#create_software_update_job(params = {}) ⇒ Types::CreateSoftwareUpdateJobResponse
Creates a software update for a core or group of cores (specified as an IoT thing group.) Use this to update the OTA Agent as well as the Greengrass core software.
-
#create_subscription_definition(params = {}) ⇒ Types::CreateSubscriptionDefinitionResponse
Creates a subscription definition.
-
#create_subscription_definition_version(params = {}) ⇒ Types::CreateSubscriptionDefinitionVersionResponse
Creates a version of a subscription definition which has already been defined.
-
#delete_connector_definition(params = {}) ⇒ Struct
Deletes a connector definition.
-
#delete_core_definition(params = {}) ⇒ Struct
Deletes a core definition.
-
#delete_device_definition(params = {}) ⇒ Struct
Deletes a device definition.
-
#delete_function_definition(params = {}) ⇒ Struct
Deletes a Lambda function definition.
-
#delete_group(params = {}) ⇒ Struct
Deletes a group.
-
#delete_logger_definition(params = {}) ⇒ Struct
Deletes a logger definition.
-
#delete_resource_definition(params = {}) ⇒ Struct
Deletes a resource definition.
-
#delete_subscription_definition(params = {}) ⇒ Struct
Deletes a subscription definition.
-
#disassociate_role_from_group(params = {}) ⇒ Types::DisassociateRoleFromGroupResponse
Disassociates the role from a group.
-
#disassociate_service_role_from_account(params = {}) ⇒ Types::DisassociateServiceRoleFromAccountResponse
Disassociates the service role from your account.
-
#get_associated_role(params = {}) ⇒ Types::GetAssociatedRoleResponse
Retrieves the role associated with a particular group.
-
#get_bulk_deployment_status(params = {}) ⇒ Types::GetBulkDeploymentStatusResponse
Returns the status of a bulk deployment.
-
#get_connectivity_info(params = {}) ⇒ Types::GetConnectivityInfoResponse
Retrieves the connectivity information for a core.
-
#get_connector_definition(params = {}) ⇒ Types::GetConnectorDefinitionResponse
Retrieves information about a connector definition.
-
#get_connector_definition_version(params = {}) ⇒ Types::GetConnectorDefinitionVersionResponse
Retrieves information about a connector definition version, including the connectors that the version contains.
-
#get_core_definition(params = {}) ⇒ Types::GetCoreDefinitionResponse
Retrieves information about a core definition version.
-
#get_core_definition_version(params = {}) ⇒ Types::GetCoreDefinitionVersionResponse
Retrieves information about a core definition version.
-
#get_deployment_status(params = {}) ⇒ Types::GetDeploymentStatusResponse
Returns the status of a deployment.
-
#get_device_definition(params = {}) ⇒ Types::GetDeviceDefinitionResponse
Retrieves information about a device definition.
-
#get_device_definition_version(params = {}) ⇒ Types::GetDeviceDefinitionVersionResponse
Retrieves information about a device definition version.
-
#get_function_definition(params = {}) ⇒ Types::GetFunctionDefinitionResponse
Retrieves information about a Lambda function definition, including its creation time and latest version.
-
#get_function_definition_version(params = {}) ⇒ Types::GetFunctionDefinitionVersionResponse
Retrieves information about a Lambda function definition version, including which Lambda functions are included in the version and their configurations.
-
#get_group(params = {}) ⇒ Types::GetGroupResponse
Retrieves information about a group.
-
#get_group_certificate_authority(params = {}) ⇒ Types::GetGroupCertificateAuthorityResponse
Retreives the CA associated with a group.
-
#get_group_certificate_configuration(params = {}) ⇒ Types::GetGroupCertificateConfigurationResponse
Retrieves the current configuration for the CA used by the group.
-
#get_group_version(params = {}) ⇒ Types::GetGroupVersionResponse
Retrieves information about a group version.
-
#get_logger_definition(params = {}) ⇒ Types::GetLoggerDefinitionResponse
Retrieves information about a logger definition.
-
#get_logger_definition_version(params = {}) ⇒ Types::GetLoggerDefinitionVersionResponse
Retrieves information about a logger definition version.
-
#get_resource_definition(params = {}) ⇒ Types::GetResourceDefinitionResponse
Retrieves information about a resource definition, including its creation time and latest version.
-
#get_resource_definition_version(params = {}) ⇒ Types::GetResourceDefinitionVersionResponse
Retrieves information about a resource definition version, including which resources are included in the version.
-
#get_service_role_for_account(params = {}) ⇒ Types::GetServiceRoleForAccountResponse
Retrieves the service role that is attached to your account.
-
#get_subscription_definition(params = {}) ⇒ Types::GetSubscriptionDefinitionResponse
Retrieves information about a subscription definition.
-
#get_subscription_definition_version(params = {}) ⇒ Types::GetSubscriptionDefinitionVersionResponse
Retrieves information about a subscription definition version.
-
#get_thing_runtime_configuration(params = {}) ⇒ Types::GetThingRuntimeConfigurationResponse
Get the runtime configuration of a thing.
-
#list_bulk_deployment_detailed_reports(params = {}) ⇒ Types::ListBulkDeploymentDetailedReportsResponse
Gets a paginated list of the deployments that have been started in a bulk deployment operation, and their current deployment status.
-
#list_bulk_deployments(params = {}) ⇒ Types::ListBulkDeploymentsResponse
Returns a list of bulk deployments.
-
#list_connector_definition_versions(params = {}) ⇒ Types::ListConnectorDefinitionVersionsResponse
Lists the versions of a connector definition, which are containers for connectors.
-
#list_connector_definitions(params = {}) ⇒ Types::ListConnectorDefinitionsResponse
Retrieves a list of connector definitions.
-
#list_core_definition_versions(params = {}) ⇒ Types::ListCoreDefinitionVersionsResponse
Lists the versions of a core definition.
-
#list_core_definitions(params = {}) ⇒ Types::ListCoreDefinitionsResponse
Retrieves a list of core definitions.
-
#list_deployments(params = {}) ⇒ Types::ListDeploymentsResponse
Returns a history of deployments for the group.
-
#list_device_definition_versions(params = {}) ⇒ Types::ListDeviceDefinitionVersionsResponse
Lists the versions of a device definition.
-
#list_device_definitions(params = {}) ⇒ Types::ListDeviceDefinitionsResponse
Retrieves a list of device definitions.
-
#list_function_definition_versions(params = {}) ⇒ Types::ListFunctionDefinitionVersionsResponse
Lists the versions of a Lambda function definition.
-
#list_function_definitions(params = {}) ⇒ Types::ListFunctionDefinitionsResponse
Retrieves a list of Lambda function definitions.
-
#list_group_certificate_authorities(params = {}) ⇒ Types::ListGroupCertificateAuthoritiesResponse
Retrieves the current CAs for a group.
-
#list_group_versions(params = {}) ⇒ Types::ListGroupVersionsResponse
Lists the versions of a group.
-
#list_groups(params = {}) ⇒ Types::ListGroupsResponse
Retrieves a list of groups.
-
#list_logger_definition_versions(params = {}) ⇒ Types::ListLoggerDefinitionVersionsResponse
Lists the versions of a logger definition.
-
#list_logger_definitions(params = {}) ⇒ Types::ListLoggerDefinitionsResponse
Retrieves a list of logger definitions.
-
#list_resource_definition_versions(params = {}) ⇒ Types::ListResourceDefinitionVersionsResponse
Lists the versions of a resource definition.
-
#list_resource_definitions(params = {}) ⇒ Types::ListResourceDefinitionsResponse
Retrieves a list of resource definitions.
-
#list_subscription_definition_versions(params = {}) ⇒ Types::ListSubscriptionDefinitionVersionsResponse
Lists the versions of a subscription definition.
-
#list_subscription_definitions(params = {}) ⇒ Types::ListSubscriptionDefinitionsResponse
Retrieves a list of subscription definitions.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of resource tags for a resource arn.
-
#reset_deployments(params = {}) ⇒ Types::ResetDeploymentsResponse
Resets a group's deployments.
-
#start_bulk_deployment(params = {}) ⇒ Types::StartBulkDeploymentResponse
Deploys multiple groups in one operation.
-
#stop_bulk_deployment(params = {}) ⇒ Struct
Stops the execution of a bulk deployment.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a Greengrass resource.
-
#untag_resource(params = {}) ⇒ Struct
Remove resource tags from a Greengrass Resource.
-
#update_connectivity_info(params = {}) ⇒ Types::UpdateConnectivityInfoResponse
Updates the connectivity information for the core.
-
#update_connector_definition(params = {}) ⇒ Struct
Updates a connector definition.
-
#update_core_definition(params = {}) ⇒ Struct
Updates a core definition.
-
#update_device_definition(params = {}) ⇒ Struct
Updates a device definition.
-
#update_function_definition(params = {}) ⇒ Struct
Updates a Lambda function definition.
-
#update_group(params = {}) ⇒ Struct
Updates a group.
-
#update_group_certificate_configuration(params = {}) ⇒ Types::UpdateGroupCertificateConfigurationResponse
Updates the Certificate expiry time for a group.
-
#update_logger_definition(params = {}) ⇒ Struct
Updates a logger definition.
-
#update_resource_definition(params = {}) ⇒ Struct
Updates a resource definition.
-
#update_subscription_definition(params = {}) ⇒ Struct
Updates a subscription definition.
-
#update_thing_runtime_configuration(params = {}) ⇒ Struct
Updates the runtime configuration of a thing.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-greengrass/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4265 4266 4267 |
# File 'lib/aws-sdk-greengrass/client.rb', line 4265 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4268 4269 4270 |
# File 'lib/aws-sdk-greengrass/client.rb', line 4268 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#associate_role_to_group(params = {}) ⇒ Types::AssociateRoleToGroupResponse
Associates a role with a group. Your Greengrass core will use the role to access AWS cloud services. The role's permissions should allow Greengrass core Lambda functions to perform actions against the cloud.
86 |
# File 'sig/client.rbs', line 86 def associate_role_to_group: ( |
#associate_service_role_to_account(params = {}) ⇒ Types::AssociateServiceRoleToAccountResponse
Associates a role with your account. AWS IoT Greengrass will use the role to access your Lambda functions and AWS IoT resources. This is necessary for deployments to succeed. The role must have at least minimum permissions in the policy ''AWSGreengrassResourceAccessRolePolicy''.
97 |
# File 'sig/client.rbs', line 97 def associate_service_role_to_account: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 |
# File 'lib/aws-sdk-greengrass/client.rb', line 4238 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Greengrass') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-greengrass' context[:gem_version] = '1.100.0' Seahorse::Client::Request.new(handlers, context) end |
#create_connector_definition(params = {}) ⇒ Types::CreateConnectorDefinitionResponse
Creates a connector definition. You may provide the initial version of the connector definition now or use ''CreateConnectorDefinitionVersion'' at a later time.
113 |
# File 'sig/client.rbs', line 113 def create_connector_definition: ( |
#create_connector_definition_version(params = {}) ⇒ Types::CreateConnectorDefinitionVersionResponse
Creates a version of a connector definition which has already been defined.
137 |
# File 'sig/client.rbs', line 137 def create_connector_definition_version: ( |
#create_core_definition(params = {}) ⇒ Types::CreateCoreDefinitionResponse
Creates a core definition. You may provide the initial version of the core definition now or use ''CreateCoreDefinitionVersion'' at a later time. Greengrass groups must each contain exactly one Greengrass core.
161 |
# File 'sig/client.rbs', line 161 def create_core_definition: ( |
#create_core_definition_version(params = {}) ⇒ Types::CreateCoreDefinitionVersionResponse
Creates a version of a core definition that has already been defined. Greengrass groups must each contain exactly one Greengrass core.
186 |
# File 'sig/client.rbs', line 186 def create_core_definition_version: ( |
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates a deployment. ''CreateDeployment'' requests are idempotent with respect to the ''X-Amzn-Client-Token'' token and the request parameters.
206 |
# File 'sig/client.rbs', line 206 def create_deployment: ( |
#create_device_definition(params = {}) ⇒ Types::CreateDeviceDefinitionResponse
Creates a device definition. You may provide the initial version of the device definition now or use ''CreateDeviceDefinitionVersion'' at a later time.
226 |
# File 'sig/client.rbs', line 226 def create_device_definition: ( |
#create_device_definition_version(params = {}) ⇒ Types::CreateDeviceDefinitionVersionResponse
Creates a version of a device definition that has already been defined.
251 |
# File 'sig/client.rbs', line 251 def create_device_definition_version: ( |
#create_function_definition(params = {}) ⇒ Types::CreateFunctionDefinitionResponse
Creates a Lambda function definition which contains a list of Lambda functions and their configurations to be used in a group. You can create an initial version of the definition by providing a list of Lambda functions and their configurations now, or use ''CreateFunctionDefinitionVersion'' later.
276 |
# File 'sig/client.rbs', line 276 def create_function_definition: ( |
#create_function_definition_version(params = {}) ⇒ Types::CreateFunctionDefinitionVersionResponse
Creates a version of a Lambda function definition that has already been defined.
297 |
# File 'sig/client.rbs', line 297 def create_function_definition_version: ( |
#create_group(params = {}) ⇒ Types::CreateGroupResponse
Creates a group. You may provide the initial version of the group or use ''CreateGroupVersion'' at a later time. Tip: You can use the ''gg_group_setup'' package (https://github.com/awslabs/aws-greengrass-group-setup) as a library or command-line application to create and deploy Greengrass groups.
318 |
# File 'sig/client.rbs', line 318 def create_group: ( |
#create_group_certificate_authority(params = {}) ⇒ Types::CreateGroupCertificateAuthorityResponse
Creates a CA for the group. If a CA already exists, it will rotate the existing CA.
339 |
# File 'sig/client.rbs', line 339 def create_group_certificate_authority: ( |
#create_group_version(params = {}) ⇒ Types::CreateGroupVersionResponse
Creates a version of a group which has already been defined.
353 |
# File 'sig/client.rbs', line 353 def create_group_version: ( |
#create_logger_definition(params = {}) ⇒ Types::CreateLoggerDefinitionResponse
Creates a logger definition. You may provide the initial version of the logger definition now or use ''CreateLoggerDefinitionVersion'' at a later time.
377 |
# File 'sig/client.rbs', line 377 def create_logger_definition: ( |
#create_logger_definition_version(params = {}) ⇒ Types::CreateLoggerDefinitionVersionResponse
Creates a version of a logger definition that has already been defined.
403 |
# File 'sig/client.rbs', line 403 def create_logger_definition_version: ( |
#create_resource_definition(params = {}) ⇒ Types::CreateResourceDefinitionResponse
Creates a resource definition which contains a list of resources to be used in a group. You can create an initial version of the definition by providing a list of resources now, or use ''CreateResourceDefinitionVersion'' later.
429 |
# File 'sig/client.rbs', line 429 def create_resource_definition: ( |
#create_resource_definition_version(params = {}) ⇒ Types::CreateResourceDefinitionVersionResponse
Creates a version of a resource definition that has already been defined.
449 |
# File 'sig/client.rbs', line 449 def create_resource_definition_version: ( |
#create_software_update_job(params = {}) ⇒ Types::CreateSoftwareUpdateJobResponse
Creates a software update for a core or group of cores (specified as an IoT thing group.) Use this to update the OTA Agent as well as the Greengrass core software. It makes use of the IoT Jobs feature which provides additional commands to manage a Greengrass core software update job.
465 |
# File 'sig/client.rbs', line 465 def create_software_update_job: ( |
#create_subscription_definition(params = {}) ⇒ Types::CreateSubscriptionDefinitionResponse
Creates a subscription definition. You may provide the initial version of the subscription definition now or use ''CreateSubscriptionDefinitionVersion'' at a later time.
487 |
# File 'sig/client.rbs', line 487 def create_subscription_definition: ( |
#create_subscription_definition_version(params = {}) ⇒ Types::CreateSubscriptionDefinitionVersionResponse
Creates a version of a subscription definition which has already been defined.
512 |
# File 'sig/client.rbs', line 512 def create_subscription_definition_version: ( |
#delete_connector_definition(params = {}) ⇒ Struct
Deletes a connector definition.
530 |
# File 'sig/client.rbs', line 530 def delete_connector_definition: ( |
#delete_core_definition(params = {}) ⇒ Struct
Deletes a core definition.
539 |
# File 'sig/client.rbs', line 539 def delete_core_definition: ( |
#delete_device_definition(params = {}) ⇒ Struct
Deletes a device definition.
548 |
# File 'sig/client.rbs', line 548 def delete_device_definition: ( |
#delete_function_definition(params = {}) ⇒ Struct
Deletes a Lambda function definition.
557 |
# File 'sig/client.rbs', line 557 def delete_function_definition: ( |
#delete_group(params = {}) ⇒ Struct
Deletes a group.
566 |
# File 'sig/client.rbs', line 566 def delete_group: ( |
#delete_logger_definition(params = {}) ⇒ Struct
Deletes a logger definition.
575 |
# File 'sig/client.rbs', line 575 def delete_logger_definition: ( |
#delete_resource_definition(params = {}) ⇒ Struct
Deletes a resource definition.
584 |
# File 'sig/client.rbs', line 584 def delete_resource_definition: ( |
#delete_subscription_definition(params = {}) ⇒ Struct
Deletes a subscription definition.
593 |
# File 'sig/client.rbs', line 593 def delete_subscription_definition: ( |
#disassociate_role_from_group(params = {}) ⇒ Types::DisassociateRoleFromGroupResponse
Disassociates the role from a group.
603 |
# File 'sig/client.rbs', line 603 def disassociate_role_from_group: ( |
#disassociate_service_role_from_account(params = {}) ⇒ Types::DisassociateServiceRoleFromAccountResponse
Disassociates the service role from your account. Without a service role, deployments will not work.
613 |
# File 'sig/client.rbs', line 613 def disassociate_service_role_from_account: ( |
#get_associated_role(params = {}) ⇒ Types::GetAssociatedRoleResponse
Retrieves the role associated with a particular group.
623 |
# File 'sig/client.rbs', line 623 def get_associated_role: ( |
#get_bulk_deployment_status(params = {}) ⇒ Types::GetBulkDeploymentStatusResponse
Returns the status of a bulk deployment.
638 |
# File 'sig/client.rbs', line 638 def get_bulk_deployment_status: ( |
#get_connectivity_info(params = {}) ⇒ Types::GetConnectivityInfoResponse
Retrieves the connectivity information for a core.
649 |
# File 'sig/client.rbs', line 649 def get_connectivity_info: ( |
#get_connector_definition(params = {}) ⇒ Types::GetConnectorDefinitionResponse
Retrieves information about a connector definition.
666 |
# File 'sig/client.rbs', line 666 def get_connector_definition: ( |
#get_connector_definition_version(params = {}) ⇒ Types::GetConnectorDefinitionVersionResponse
Retrieves information about a connector definition version, including the connectors that the version contains. Connectors are prebuilt modules that interact with local infrastructure, device protocols, AWS, and other cloud services.
681 |
# File 'sig/client.rbs', line 681 def get_connector_definition_version: ( |
#get_core_definition(params = {}) ⇒ Types::GetCoreDefinitionResponse
Retrieves information about a core definition version.
700 |
# File 'sig/client.rbs', line 700 def get_core_definition: ( |
#get_core_definition_version(params = {}) ⇒ Types::GetCoreDefinitionVersionResponse
Retrieves information about a core definition version.
715 |
# File 'sig/client.rbs', line 715 def get_core_definition_version: ( |
#get_deployment_status(params = {}) ⇒ Types::GetDeploymentStatusResponse
Returns the status of a deployment.
730 |
# File 'sig/client.rbs', line 730 def get_deployment_status: ( |
#get_device_definition(params = {}) ⇒ Types::GetDeviceDefinitionResponse
Retrieves information about a device definition.
748 |
# File 'sig/client.rbs', line 748 def get_device_definition: ( |
#get_device_definition_version(params = {}) ⇒ Types::GetDeviceDefinitionVersionResponse
Retrieves information about a device definition version.
763 |
# File 'sig/client.rbs', line 763 def get_device_definition_version: ( |
#get_function_definition(params = {}) ⇒ Types::GetFunctionDefinitionResponse
Retrieves information about a Lambda function definition, including its creation time and latest version.
782 |
# File 'sig/client.rbs', line 782 def get_function_definition: ( |
#get_function_definition_version(params = {}) ⇒ Types::GetFunctionDefinitionVersionResponse
Retrieves information about a Lambda function definition version, including which Lambda functions are included in the version and their configurations.
797 |
# File 'sig/client.rbs', line 797 def get_function_definition_version: ( |
#get_group(params = {}) ⇒ Types::GetGroupResponse
Retrieves information about a group.
816 |
# File 'sig/client.rbs', line 816 def get_group: ( |
#get_group_certificate_authority(params = {}) ⇒ Types::GetGroupCertificateAuthorityResponse
Retreives the CA associated with a group. Returns the public key of the CA.
828 |
# File 'sig/client.rbs', line 828 def get_group_certificate_authority: ( |
#get_group_certificate_configuration(params = {}) ⇒ Types::GetGroupCertificateConfigurationResponse
Retrieves the current configuration for the CA used by the group.
841 |
# File 'sig/client.rbs', line 841 def get_group_certificate_configuration: ( |
#get_group_version(params = {}) ⇒ Types::GetGroupVersionResponse
Retrieves information about a group version.
855 |
# File 'sig/client.rbs', line 855 def get_group_version: ( |
#get_logger_definition(params = {}) ⇒ Types::GetLoggerDefinitionResponse
Retrieves information about a logger definition.
873 |
# File 'sig/client.rbs', line 873 def get_logger_definition: ( |
#get_logger_definition_version(params = {}) ⇒ Types::GetLoggerDefinitionVersionResponse
Retrieves information about a logger definition version.
887 |
# File 'sig/client.rbs', line 887 def get_logger_definition_version: ( |
#get_resource_definition(params = {}) ⇒ Types::GetResourceDefinitionResponse
Retrieves information about a resource definition, including its creation time and latest version.
906 |
# File 'sig/client.rbs', line 906 def get_resource_definition: ( |
#get_resource_definition_version(params = {}) ⇒ Types::GetResourceDefinitionVersionResponse
Retrieves information about a resource definition version, including which resources are included in the version.
920 |
# File 'sig/client.rbs', line 920 def get_resource_definition_version: ( |
#get_service_role_for_account(params = {}) ⇒ Types::GetServiceRoleForAccountResponse
Retrieves the service role that is attached to your account.
932 |
# File 'sig/client.rbs', line 932 def get_service_role_for_account: ( |
#get_subscription_definition(params = {}) ⇒ Types::GetSubscriptionDefinitionResponse
Retrieves information about a subscription definition.
948 |
# File 'sig/client.rbs', line 948 def get_subscription_definition: ( |
#get_subscription_definition_version(params = {}) ⇒ Types::GetSubscriptionDefinitionVersionResponse
Retrieves information about a subscription definition version.
963 |
# File 'sig/client.rbs', line 963 def get_subscription_definition_version: ( |
#get_thing_runtime_configuration(params = {}) ⇒ Types::GetThingRuntimeConfigurationResponse
Get the runtime configuration of a thing.
975 |
# File 'sig/client.rbs', line 975 def get_thing_runtime_configuration: ( |
#list_bulk_deployment_detailed_reports(params = {}) ⇒ Types::ListBulkDeploymentDetailedReportsResponse
Gets a paginated list of the deployments that have been started in a bulk deployment operation, and their current deployment status.
986 |
# File 'sig/client.rbs', line 986 def list_bulk_deployment_detailed_reports: ( |
#list_bulk_deployments(params = {}) ⇒ Types::ListBulkDeploymentsResponse
Returns a list of bulk deployments.
999 |
# File 'sig/client.rbs', line 999 def list_bulk_deployments: ( |
#list_connector_definition_versions(params = {}) ⇒ Types::ListConnectorDefinitionVersionsResponse
Lists the versions of a connector definition, which are containers for connectors. Connectors run on the Greengrass core and contain built-in integration with local infrastructure, device protocols, AWS, and other cloud services.
1011 |
# File 'sig/client.rbs', line 1011 def list_connector_definition_versions: ( |
#list_connector_definitions(params = {}) ⇒ Types::ListConnectorDefinitionsResponse
Retrieves a list of connector definitions.
1024 |
# File 'sig/client.rbs', line 1024 def list_connector_definitions: ( |
#list_core_definition_versions(params = {}) ⇒ Types::ListCoreDefinitionVersionsResponse
Lists the versions of a core definition.
1036 |
# File 'sig/client.rbs', line 1036 def list_core_definition_versions: ( |
#list_core_definitions(params = {}) ⇒ Types::ListCoreDefinitionsResponse
Retrieves a list of core definitions.
1049 |
# File 'sig/client.rbs', line 1049 def list_core_definitions: ( |
#list_deployments(params = {}) ⇒ Types::ListDeploymentsResponse
Returns a history of deployments for the group.
1061 |
# File 'sig/client.rbs', line 1061 def list_deployments: ( |
#list_device_definition_versions(params = {}) ⇒ Types::ListDeviceDefinitionVersionsResponse
Lists the versions of a device definition.
1074 |
# File 'sig/client.rbs', line 1074 def list_device_definition_versions: ( |
#list_device_definitions(params = {}) ⇒ Types::ListDeviceDefinitionsResponse
Retrieves a list of device definitions.
1087 |
# File 'sig/client.rbs', line 1087 def list_device_definitions: ( |
#list_function_definition_versions(params = {}) ⇒ Types::ListFunctionDefinitionVersionsResponse
Lists the versions of a Lambda function definition.
1099 |
# File 'sig/client.rbs', line 1099 def list_function_definition_versions: ( |
#list_function_definitions(params = {}) ⇒ Types::ListFunctionDefinitionsResponse
Retrieves a list of Lambda function definitions.
1112 |
# File 'sig/client.rbs', line 1112 def list_function_definitions: ( |
#list_group_certificate_authorities(params = {}) ⇒ Types::ListGroupCertificateAuthoritiesResponse
Retrieves the current CAs for a group.
1123 |
# File 'sig/client.rbs', line 1123 def list_group_certificate_authorities: ( |
#list_group_versions(params = {}) ⇒ Types::ListGroupVersionsResponse
Lists the versions of a group.
1134 |
# File 'sig/client.rbs', line 1134 def list_group_versions: ( |
#list_groups(params = {}) ⇒ Types::ListGroupsResponse
Retrieves a list of groups.
1147 |
# File 'sig/client.rbs', line 1147 def list_groups: ( |
#list_logger_definition_versions(params = {}) ⇒ Types::ListLoggerDefinitionVersionsResponse
Lists the versions of a logger definition.
1159 |
# File 'sig/client.rbs', line 1159 def list_logger_definition_versions: ( |
#list_logger_definitions(params = {}) ⇒ Types::ListLoggerDefinitionsResponse
Retrieves a list of logger definitions.
1172 |
# File 'sig/client.rbs', line 1172 def list_logger_definitions: ( |
#list_resource_definition_versions(params = {}) ⇒ Types::ListResourceDefinitionVersionsResponse
Lists the versions of a resource definition.
1184 |
# File 'sig/client.rbs', line 1184 def list_resource_definition_versions: ( |
#list_resource_definitions(params = {}) ⇒ Types::ListResourceDefinitionsResponse
Retrieves a list of resource definitions.
1197 |
# File 'sig/client.rbs', line 1197 def list_resource_definitions: ( |
#list_subscription_definition_versions(params = {}) ⇒ Types::ListSubscriptionDefinitionVersionsResponse
Lists the versions of a subscription definition.
1209 |
# File 'sig/client.rbs', line 1209 def list_subscription_definition_versions: ( |
#list_subscription_definitions(params = {}) ⇒ Types::ListSubscriptionDefinitionsResponse
Retrieves a list of subscription definitions.
1222 |
# File 'sig/client.rbs', line 1222 def list_subscription_definitions: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of resource tags for a resource arn.
1233 |
# File 'sig/client.rbs', line 1233 def list_tags_for_resource: ( |
#reset_deployments(params = {}) ⇒ Types::ResetDeploymentsResponse
Resets a group's deployments.
1244 |
# File 'sig/client.rbs', line 1244 def reset_deployments: ( |
#start_bulk_deployment(params = {}) ⇒ Types::StartBulkDeploymentResponse
Deploys multiple groups in one operation. This action starts the bulk deployment of a specified set of group versions. Each group version deployment will be triggered with an adaptive rate that has a fixed upper limit. We recommend that you include an ''X-Amzn-Client-Token'' token in every ''StartBulkDeployment'' request. These requests are idempotent with respect to the token and the request parameters.
1257 |
# File 'sig/client.rbs', line 1257 def start_bulk_deployment: ( |
#stop_bulk_deployment(params = {}) ⇒ Struct
Stops the execution of a bulk deployment. This action returns a status of ''Stopping'' until the deployment is stopped. You cannot start a new bulk deployment while a previous deployment is in the ''Stopping'' state. This action doesn't rollback completed deployments or cancel pending deployments.
1269 |
# File 'sig/client.rbs', line 1269 def stop_bulk_deployment: ( |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a Greengrass resource. Valid resources are 'Group', 'ConnectorDefinition', 'CoreDefinition', 'DeviceDefinition', 'FunctionDefinition', 'LoggerDefinition', 'SubscriptionDefinition', 'ResourceDefinition', and 'BulkDeployment'.
1275 |
# File 'sig/client.rbs', line 1275 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Remove resource tags from a Greengrass Resource.
1282 |
# File 'sig/client.rbs', line 1282 def untag_resource: ( |
#update_connectivity_info(params = {}) ⇒ Types::UpdateConnectivityInfoResponse
Updates the connectivity information for the core. Any devices that belong to the group which has this core will receive this information in order to find the location of the core and connect to it.
1294 |
# File 'sig/client.rbs', line 1294 def update_connectivity_info: ( |
#update_connector_definition(params = {}) ⇒ Struct
Updates a connector definition.
1311 |
# File 'sig/client.rbs', line 1311 def update_connector_definition: ( |
#update_core_definition(params = {}) ⇒ Struct
Updates a core definition.
1321 |
# File 'sig/client.rbs', line 1321 def update_core_definition: ( |
#update_device_definition(params = {}) ⇒ Struct
Updates a device definition.
1331 |
# File 'sig/client.rbs', line 1331 def update_device_definition: ( |
#update_function_definition(params = {}) ⇒ Struct
Updates a Lambda function definition.
1341 |
# File 'sig/client.rbs', line 1341 def update_function_definition: ( |
#update_group(params = {}) ⇒ Struct
Updates a group.
1351 |
# File 'sig/client.rbs', line 1351 def update_group: ( |
#update_group_certificate_configuration(params = {}) ⇒ Types::UpdateGroupCertificateConfigurationResponse
Updates the Certificate expiry time for a group.
1364 |
# File 'sig/client.rbs', line 1364 def update_group_certificate_configuration: ( |
#update_logger_definition(params = {}) ⇒ Struct
Updates a logger definition.
1374 |
# File 'sig/client.rbs', line 1374 def update_logger_definition: ( |
#update_resource_definition(params = {}) ⇒ Struct
Updates a resource definition.
1384 |
# File 'sig/client.rbs', line 1384 def update_resource_definition: ( |
#update_subscription_definition(params = {}) ⇒ Struct
Updates a subscription definition.
1394 |
# File 'sig/client.rbs', line 1394 def update_subscription_definition: ( |
#update_thing_runtime_configuration(params = {}) ⇒ Struct
Updates the runtime configuration of a thing.
1404 |
# File 'sig/client.rbs', line 1404 def update_thing_runtime_configuration: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4258 4259 4260 |
# File 'lib/aws-sdk-greengrass/client.rb', line 4258 def waiter_names [] end |